state_forge_core library

Pure Dart core primitives for StateForge.

Classes

AsyncState<T>
A universal sealed class for representing asynchronous states.
EffectStore<S, E extends Object>
A Store that declares the type of one-time effect it emits.
Failure<T>
The state when an asynchronous action has failed.
ForgeDisposable
A resource with explicit cleanup semantics.
ForgeObserver
An abstract class for observing the lifecycle, state transitions, and side effects of all Stores globally.
ForgeStorageAdapter
Storage contract used by PersistableStore.
Idle<T>
The initial state before any action has been taken.
Loading<T>
The state when an asynchronous action is in progress.
StateForge
Global configuration and hooks for the StateForge library.
StateForgeDiagnostics
Diagnostics hooks used by platform adapters such as the Flutter package.
Store<S>
The foundation for all business logic in StateForge.
Success<T>
The state when an asynchronous action has completed successfully.

Mixins

CompositedStore<S>
A mixin that allows a Store to reactively depend on other Stores.
PersistableStore<S>
A mixin that defines a contract for state persistence in a Store.
UndoableStore<S>
A mixin that adds history management (Undo/Redo) to a Store.

Typedefs

StoreListener = void Function()
A callback invoked when a Store notifies listeners.